==========
How to ...
==========

The `csdmpy` module is not just designed for deserializing and serializing
the `.csdf` or `.csdfe` files. It can also be used to create new datasets,
a feature that is most useful when converting dataset to csdm compliant format.

.. toctree::
    :maxdepth: 2

    new_dataset
    new_dimensions
    new_dependent_variables
    save_dataset
    A fun example
